var baseHandler = require('./base-obj-to-css');

// https://blogs.msdn.microsoft.com/ieinternals/2011/05/14/stylesheet-limits-in-internet-explorer/
var IE9_RULE_LIMIT = 4095;

module.exports = cacheToStylesheetsOldIE;

/*
 * Converts cache object to a CSS string
 * @param  {object} cacheObj Cache object
 * @return {string}          String of CSS
 */
function cacheToStylesheetsOldIE(cacheObj) {
  var sheets = [];
  var mediaSheets;
  var mainCss = '';
  var ruleCount = 0;
  for (var key in cacheObj) {
    if (key === 'media') {
      mediaSheets = getMediaSheets(cacheObj[key]);
      continue;
    }
    ruleCount += Object.keys(cacheObj[key]).length;
    mainCss += baseHandler(key, cacheObj[key]);
    // TODO: handle case of than 4095 unique values for a single property
    if (ruleCount > IE9_RULE_LIMIT && mainCss) {
      sheets.push({css: mainCss});
      mainCss = '';
      ruleCount = 0;
    }
  }
  if (mainCss) {
    sheets.push({css: mainCss});
  }
  return mediaSheets ? sheets.concat(mediaSheets) : sheets;
}

function getMediaSheets(mediaObj) {
  var stylesheets = [];
  for (var query in mediaObj) {
    var obj = mediaObj[query];
    var mediaCss = '';
    var ruleCount = 0;
    for (var key in obj) {
      ruleCount += Object.keys(obj[key]).length;
      // TODO: handle case of than 4095 unique values for a single property
      if (ruleCount > IE9_RULE_LIMIT && mediaCss) {
        stylesheets.push({media: query, css: mediaCss});
        mediaCss = '';
        ruleCount = 0;
      }
      mediaCss += baseHandler(key, obj[key]);
    }
    if (mediaCss) {
      stylesheets.push({
        media: query,
        css: mediaCss
      });
    }
  }
  return stylesheets;
}
