var test = require('tape');
var fixtures = require('test-fixtures');

var cacheToCss = require('../cache-to-css');
var Styletron = require('../styletron-server');

var StyletronTest = (function (Styletron) {
  function StyletronTest() {
    var args = [], len = arguments.length;
    while ( len-- ) args[ len ] = arguments[ len ];

    Styletron.apply(this, args);
  }

  if ( Styletron ) StyletronTest.__proto__ = Styletron;
  StyletronTest.prototype = Object.create( Styletron && Styletron.prototype );
  StyletronTest.prototype.constructor = StyletronTest;
  StyletronTest.prototype.setCache = function setCache (cache) {
    this.cache = cache;
  };

  return StyletronTest;
}(Styletron));

test('test toCss', function (t) {
  t.equal(cacheToCss(fixtures.basic.cache), fixtures.basic.css);
  t.end();
});

test('test getCss method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.equal(instance.getCss(), fixtures.basic.css);
  t.end();
});

test('test getStylesheets method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.deepEqual(instance.getStylesheets(), [
    {
      css: '.s4:hover{display:none}.s0{color:red}.s1{color:green}'
    },
    {
      media: '(max-width: 800px)',
      css: '.s3:hover{color:green}.s2{color:green}'
    }
  ]);
  t.end();
});

test('test getStylesheetsHtml method', function (t) {
  var instance = new StyletronTest();
  instance.setCache(fixtures.basic.cache);
  t.equal(instance.getStylesheetsHtml(), '<style class="_styletron_hydrate_">.s4:hover{display:none}.s0{color:red}.s1{color:green}</style><style class="_styletron_hydrate_" media="(max-width: 800px)">.s3:hover{color:green}.s2{color:green}</style>');
  t.end();
});

test('test getStylesheetsOldIE method', function (t) {
  var instance = new StyletronTest();
  for (var i = 0; i <= 4095; i++) {
    instance.injectDeclaration({prop: 'font-size', val: (i + "px")});
  }
  t.equal(instance.getStylesheetsOldIE().length, 1, 'only one sheet');
  instance.injectDeclaration({prop: 'color', val: 'red'});
  t.equal(instance.getStylesheetsOldIE().length, 2, 'rollover into another sheet');
  for (var i$1 = 0; i$1 <= 4095; i$1++) {
    instance.injectDeclaration({prop: 'font-size', val: (i$1 + "px"), media: '(max-width: 400px)'});
  }
  t.equal(instance.getStylesheetsOldIE().length, 3, 'media sheet');
  instance.injectDeclaration({prop: 'color', val: 'red', media: '(max-width: 400px)'});
  t.equal(instance.getStylesheetsOldIE().length, 4, 'media sheet rollover');
  t.end();
});
